@@ -16,7 +16,10 @@ __all__ = ('MultiStream', )
 
 class MultiStream(Stream):
     """
-    Create a MultiStream object that defines material flow rates for multiple phases along with its thermodynamic state. Thermodynamic and transport properties of a stream are available as properties, while thermodynamic equilbrium (e.g. VLE, and bubble and dew points) are available as methods. 
+    Create a MultiStream object that defines material flow rates for multiple
+    phases along with its thermodynamic state. Thermodynamic and transport
+    properties of a stream are available as properties, while thermodynamic
+    equilbrium (e.g. VLE, and bubble and dew points) are available as methods. 
 
     Parameters
     ----------
@@ -130,8 +133,10 @@ class MultiStream(Stream):
     
     """
     __slots__ = ()
-    def __init__(self, ID="", flow=(), T=298.15, P=101325., phases=('g', 'l'), units=None,
+    def __init__(self, ID="", flow=(), T=298.15, P=101325.,
+                 phases=('g', 'l'), units=None,
                  thermo=None, price=0, **phase_flows):
+        self.path_priority = 0
         self._TP = ThermalCondition(T, P)
         thermo = self._load_thermo(thermo)
         self._init_indexer(flow, phases, thermo.chemicals, phase_flows)
