@@ -61,8 +61,7 @@ class Stream:
     Before creating a stream, first set the chemicals:
         
     >>> import thermosteam as tmo
-    >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-    >>> tmo.settings.set_thermo(chemicals)
+    >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
     
     Create a stream, defining the thermodynamic condition and flow rates:
         
@@ -183,7 +182,7 @@ class Stream:
      flow (kmol/hr): (g) Water    0.4721
                          Ethanol  0.1916
                      (l) Water    0.6381
-                         Ethanol  0.02551
+                         Ethanol  0.02552
     
     Note that the stream is a now a MultiStream to manage multiple phases.
     Each phase can be accessed separately too:
@@ -203,7 +202,8 @@ class Stream:
     """
     __slots__ = ('_ID', '_imol', '_TP', '_thermo', '_streams',
                  '_bubble_point_cache', '_dew_point_cache',
-                 '_vle_cache', '_sink', '_source', '_price')
+                 '_vle_cache', '_sink', '_source', '_price',
+                 'path_priority')
     line = 'Stream'
     
     #: [DisplayUnits] Units of measure for IPython display (class attribute)
@@ -215,6 +215,9 @@ class Stream:
 
     def __init__(self, ID='', flow=(), phase='l', T=298.15, P=101325., units='kmol/hr',
                  price=0., thermo=None, **chemical_flows):
+        #: [bool] True if BioSTEAM should follow this stream's path first when 
+        # creating systems.
+        self.path_priority = 0
         self._TP = ThermalCondition(T, P)
         thermo = self._load_thermo(thermo)
         self._init_indexer(flow, phase, thermo.chemicals, chemical_flows)
@@ -287,8 +290,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals)
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.get_flow('kg/hr', 'Water')
         20.0
@@ -314,8 +316,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals)
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
         >>> s1 = tmo.Stream(ID='s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.set_flow(10, 'kg/hr', 'Water')
         >>> s1.get_flow('kg/hr', 'Water')
@@ -338,8 +339,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals)
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.get_total_flow('kg/hr')
         30.0
@@ -363,8 +363,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals)
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.set_total_flow(1.0,'kg/hr')
         >>> s1.get_total_flow('kg/hr')
@@ -388,8 +387,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.get_property('sigma', 'N/m') # Surface tension
         0.06384967976396348
@@ -424,8 +422,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.set_property('P', 2, 'atm')
         >>> s1.P
@@ -568,7 +565,7 @@ class Stream:
     def F_vol(self, value):
         F_vol = self.F_vol
         if not F_vol: raise AttributeError("undefined composition; cannot set flow rate")
-        self.ivol._data[:] *= value / F_vol / 1000.
+        self.imol._data[:] *= value / F_vol
     
     @property
     def H(self):
@@ -694,8 +691,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = s1.copy()
         >>> s1.mix_from([s1, s2])
@@ -725,7 +721,7 @@ class Stream:
         --------
         >>> import thermosteam as tmo
         >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(chemicals)
         >>> s = tmo.Stream('s', Water=20, Ethanol=10, units='kg/hr')
         >>> s1 = tmo.Stream('s1')
         >>> s2 = tmo.Stream('s2')
@@ -766,8 +762,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = tmo.Stream('s2')
         >>> s2.link_with(s1)
@@ -801,8 +796,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = tmo.Stream('s2')
         >>> s2.link_with(s1)
@@ -824,8 +818,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = tmo.Stream('s2', Water=2, units='kg/hr')
         >>> s1.copy_like(s2)
@@ -857,8 +850,7 @@ class Stream:
         Initialize streams:
         
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = tmo.Stream('s2')
         
@@ -923,8 +915,7 @@ class Stream:
         Create a copy of a new stream:
         
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1_copy = s1.copy('s1_copy')
         >>> s1_copy.show(flow='kg/hr')
@@ -940,6 +931,7 @@ class Stream:
         """
         cls = self.__class__
         new = cls.__new__(cls)
+        new.path_priority = 0
         new._sink = new._source = None
         new._thermo = self._thermo
         new._imol = self._imol.copy()
@@ -956,8 +948,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s2 = s1.flow_proxy()
         >>> s2.mol is s1.mol
@@ -975,14 +966,40 @@ class Stream:
         new._init_cache()
         return new
     
+    def proxy(self):
+        """Return a new stream that shares all data with this one.
+        
+        Examples
+        --------
+        >>> import thermosteam as tmo
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
+        >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
+        >>> s2 = s1.proxy()
+        >>> s2.imol is s1.imol and s2.thermal_condition is s1.thermal_condition
+        True
+        
+        """
+        cls = self.__class__
+        new = cls.__new__(cls)
+        new._sink = new._source = new._ID = None
+        new.price = self.price
+        new._thermo = self._thermo
+        new._imol = self._imol
+        new._TP = self._TP
+        new._bubble_point_cache = self._bubble_point_cache
+        new._dew_point_cache = self._dew_point_cache
+        try: new._vle_cache = self._vle_cache
+        except AttributeError: pass
+        new.path_priority = self.path_priority
+        return new
+    
     def empty(self):
         """Empty stream flow rates.
         
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, units='kg/hr')
         >>> s1.empty()
         >>> s1.F_mol
@@ -1019,8 +1036,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.get_bubble_point()
         BubblePoint([Water, Ethanol])
@@ -1042,8 +1058,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.get_dew_point()
         DewPoint([Water, Ethanol])
@@ -1065,15 +1080,14 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.bubble_point_at_T()
         BubblePointValues(T=350, P=76621.54388128374, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.486 0.514])
         
         """
         bp = self.get_bubble_point(IDs)
-        z = self.get_molar_composition(bp.IDs)
+        z = self.get_normalized_mol(bp.IDs)
         return bp(z, T=T or self.T)
     
     def bubble_point_at_P(self, P=None, IDs=None):
@@ -1088,15 +1102,14 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol'])
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.bubble_point_at_P()
         BubblePointValues(T=357.0881141715846, P=101325.0, IDs=('Water', 'Ethanol'), z=[0.836 0.164], y=[0.49 0.51])
         
         """
         bp = self.get_bubble_point(IDs)
-        z = self.get_molar_composition(bp.IDs)
+        z = self.get_normalized_mol(bp.IDs)
         return bp(z, P=P or self.P)
     
     def dew_point_at_T(self, T=None, IDs=None):
@@ -1111,15 +1124,14 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.dew_point_at_T()
         DewPointValues(T=350, P=48990.56398459762, IDs=('Water', 'Ethanol'), z=[0.836 0.164], x=[0.984 0.016])
         
         """
         dp = self.get_dew_point(IDs)
-        z = self.get_molar_composition(dp.IDs)
+        z = self.get_normalized_mol(dp.IDs)
         return dp(z, T=T or self.T)
     
     def dew_point_at_P(self, P=None, IDs=None):
@@ -1134,15 +1146,14 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, T=350, units='kg/hr')
         >>> s1.dew_point_at_P()
         DewPointValues(T=368.6573659718087, P=101325.0, IDs=('Water', 'Ethanol'), z=[0.836 0.164], x=[0.984 0.016])
         
         """
         dp = self.get_dew_point(IDs)
-        z = self.get_molar_composition(dp.IDs)
+        z = self.get_normalized_mol(dp.IDs)
         return dp(z, P=P or self.P)
     
     def get_normalized_mol(self, IDs):
@@ -1157,8 +1168,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol', 'Methanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='kmol/hr')
         >>> s1.get_normalized_mol(('Water', 'Ethanol'))
         array([0.667, 0.333])
@@ -1180,8 +1190,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol', 'Methanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol'])
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='kg/hr')
         >>> s1.get_normalized_mass(('Water', 'Ethanol'))
         array([0.667, 0.333])
@@ -1202,8 +1211,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol', 'Methanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='m3/hr')
         >>> s1.get_normalized_vol(('Water', 'Ethanol'))
         array([0.667, 0.333])
@@ -1224,8 +1232,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol', 'Methanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='kmol/hr')
         >>> s1.get_molar_composition(('Water', 'Ethanol'))
         array([0.5 , 0.25])
@@ -1245,8 +1252,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol', 'Methanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='kg/hr')
         >>> s1.get_mass_composition(('Water', 'Ethanol'))
         array([0.5 , 0.25])
@@ -1266,8 +1272,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol', 'Methanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='m3/hr')
         >>> s1.get_volumetric_composition(('Water', 'Ethanol'))
         array([0.5 , 0.25])
@@ -1287,8 +1292,7 @@ class Stream:
         Examples
         --------
         >>> import thermosteam as tmo
-        >>> chemicals = tmo.Chemicals(['Water', 'Ethanol', 'Methanol'])
-        >>> tmo.settings.set_thermo(chemicals) 
+        >>> tmo.settings.set_thermo(['Water', 'Ethanol', 'Methanol']) 
         >>> s1 = tmo.Stream('s1', Water=20, Ethanol=10, Methanol=10, units='m3/hr')
         >>> s1.get_concentration(('Water', 'Ethanol'))
         array([27.823,  4.265])
@@ -1296,9 +1300,19 @@ class Stream:
         """
         return self.imol[IDs]/self.F_vol
     
-    def recieve_vent(self, other, accumulate=False):
+    @property
+    def P_vapor(self):
+        """Vapor pressure of liquid."""
+        chemicals = self.equilibrium_chemicals
+        F_l = eq.LiquidFugacities(chemicals, self.thermo)
+        IDs = tuple([i.ID for i in chemicals])
+        x = self.get_molar_composition(IDs)
+        T = self.T
+        return F_l(x, T).sum()
+    
+    def receive_vent(self, other, accumulate=False):
         """
-        Recieve vapors from another stream as if in equilibrium.
+        Receive vapors from another stream as if in equilibrium.
 
         Parameters
         ----------
@@ -1313,7 +1327,7 @@ class Stream:
         >>> tmo.settings.set_thermo(chemicals) 
         >>> s1 = tmo.Stream('s1', N2=10, units='m3/hr', phase='g', T=330)
         >>> s2 = tmo.Stream('s2', Water=10, Ethanol=2, T=330)
-        >>> s1.recieve_vent(s2, accumulate=True)
+        >>> s1.receive_vent(s2, accumulate=True)
         >>> s1.show(flow='kmol/hr')
         Stream: s1
          phase: 'g', T: 330 K, P: 101325 Pa
@@ -1355,12 +1369,20 @@ class Stream:
         self.__class__ = ms.MultiStream
         self._imol = self._imol.to_material_indexer(phases)
         self._streams = {}
-        self._vle_cache = Cache(eq.VLE, self._imol, self._TP, thermo=self._thermo,
+        self._vle_cache = Cache(eq.VLE, self._imol, self._TP,
+                                thermo=self._thermo,
                                 bubble_point_cache=self._bubble_point_cache,
                                 dew_point_cache=self._dew_point_cache)
     
     ### Representation ###
     
+    def diagram(self, file=None, format='png'):
+        from biosteam._digraph import make_digraph, save_digraph
+        units = [i for i in (self.source, self.sink) if i]
+        streams = sum([i.ins + i.outs for i in units], [])
+        f = make_digraph(units, set(streams))
+        save_digraph(f, file, format)
+    
     def _basic_info(self):
         return f"{type(self).__name__}: {self.ID or ''}\n"
     
